/*
 *  
 *  $Id: herramientainterpolate.h 4478 2011-12-13 11:55:00Z carlos $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
 *  See License.txt for details
 *
 *
 */
#pragma once

#include <export/iherramientainterpolate.h>
#include <api/api.h>

#include <map>

class HerramientaOpcionesGUIBase;

namespace GNC {

	class EXTAPI HerramientaInterpolate : public GNC::GCS::IHerramientaInterpolate {

	protected:

	public:
		HerramientaInterpolate();
		~HerramientaInterpolate();
		//menu de la rejilla
		virtual bool AppendInMenu(wxWindow* pParent, wxMenu* pMenuParent);

		//region "Realización de la interfaz IHerramienta"

		// Setup de paneles
		virtual void CrearPaneles( wxPanel* panel );

		//endregion

		bool IsSet();
		//cuando hacen click en ella...
		virtual void SolicitarActivacion(const GNC::GCS::TriggerButton& buttonmask);

		virtual void ConectarContratoFalso(bool activar);
		virtual void SetVistaActiva(GNC::GCS::IVista* pVista);
		virtual void ConectarContratos(bool activar);


	protected:

	};
}
